==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/Sporetrap.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1267;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;

public class Sporetrap extends class_1314 {
	public Sporetrap(class_1299<Sporetrap> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5959() {
		super.method_5959();
		field_6201.method_6277(0, new class_1347(this));
		field_6201.method_6277(1, new class_1366(this, 1.0D, false));
		field_6201.method_6277(2, new class_1361(this, class_1657.class, 16.0F));
		field_6185.method_6277(1, new class_1399(this));
		field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
	}

	public static class_5132.class_5133 createAttributes() {
		return class_1308.method_26828()
				.method_26868(class_5134.field_23719, 0.1F)
				.method_26868(class_5134.field_23718, 5.0D)
				.method_26868(class_5134.field_23717, 16.0D)
				.method_26868(class_5134.field_23716, 35.0D)
				.method_26868(class_5134.field_23721, 8.0D)
				.method_26868(class_5134.field_23723, 5.0D)
				.method_26868(class_5134.field_23722, 0.0D);
	}

	public static boolean canSpawn(class_1299<Sporetrap> entity, class_1936 levelAccess, class_3730 spawnType, class_2338 pos, class_5819 random) {
		return class_1314.method_20636(entity, levelAccess, spawnType, pos, random)
				&& levelAccess instanceof final class_1937 level && level.method_8407() != class_1267.field_5801;
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/Sporetrap.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1267;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;

public class Sporetrap extends class_1314 {
	public Sporetrap(class_1299<Sporetrap> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5959() {
		super.method_5959();
		field_6201.method_6277(0, new class_1347(this));
		field_6201.method_6277(1, new class_1366(this, 1.0D, false));
		field_6201.method_6277(2, new class_1361(this, class_1657.class, 16.0F));
		field_6185.method_6277(1, new class_1399(this));
		field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
	}

	public static class_5132.class_5133 createAttributes() {
		return class_1308.method_26828()
				.method_26868(class_5134.field_23719, 0.1F)
				.method_26868(class_5134.field_23718, 5.0D)
				.method_26868(class_5134.field_23717, 16.0D)
				.method_26868(class_5134.field_23716, 35.0D)
				.method_26868(class_5134.field_23721, 8.0D)
				.method_26868(class_5134.field_23723, 5.0D)
				.method_26868(class_5134.field_23722, 0.0D);
	}

	public static boolean canSpawn(class_1299<Sporetrap> entity, class_1936 levelAccess, class_3730 reason, class_2338 pos, class_5819 random) {
		return class_1314.method_20636(entity, levelAccess, reason, pos, random) && levelAccess instanceof final class_1937 level && level.method_8407() != class_1267.field_5801;
	}
}
